/**
  *  \file net/config.cpp
  *  \brief Network Configuration
  *  \author Stefan Reuther
  *
  *  This module provides an interface between the config file reader
  *  and the network configuration items.
  *
  *  \todo We could actually store network configuration here, and
  *  reference it form the specific classes.
  */

#include "net/config.h"
#include "enumerator.h"
#include "net/smtp.h"
#include "net/http.h"
#include "util.h"
#include "net/url.h"
#include "nls.h"

/** Static instance of SmtpConfig. */
SmtpConfig SmtpConfig::instance;

void
SmtpConfig::enumerate(KVEnumerator& e)
{
    e.handleItem("server", _("Outgoing mail (SMTP) Server"), Smtp::getServer());
    if (Smtp::getPort() != 25)
        e.handleItem("port", _("Port on outgoing mail (SMTP) Server"), itoa(Smtp::getPort()));
    else
        e.handleItem("port", _("Port on outgoing mail (SMTP) Server"), "");
    e.handleItem("useraddress", _("Your email address (to use as 'From' for turn emails)"), Smtp::getFromAddress());
}

bool
SmtpConfig::assign(std::string name, std::string value, LoaderState& /*st*/)
{
    if (name == "server") {
        Smtp::setServer(value, Smtp::getPort());
        return true;
    } else if (name == "port") {
        int n;
        if (atoi(value, n) && n > 0) {
            Smtp::setServer(Smtp::getServer(), n);
            return true;
        } else {
            return false;
        }
    } else if (name == "useraddress") {
        Smtp::setFromAddress(value);
        return true;
    } else {
        return false;
    }
}

/** Static instance of HttpConfig. */
HttpConfig HttpConfig::instance;

void
HttpConfig::enumerate(KVEnumerator& e)
{
    e.handleItem("proxy", _("HTTP Proxy"), Http::getProxy().toString());
}

bool
HttpConfig::assign(std::string name, std::string value, LoaderState& /*st*/)
{
    if (name == "proxy") {
        Url u;
        if (u.parse(value)) {
            Http::setProxy(u);
            return true;
        } else {
            return false;
        }
    } else {
        return false;
    }
}
