/**
  *  \file http.h
  *  \brief HTTP Access
  *  \author Stefan Reuther
  */
#ifndef HTTP_H_INCLUDED
#define HTTP_H_INCLUDED

#include <string>
#include <ostream>
#include <list>
#include "enumerator.h"
#include "net/url.h"
#include "net/connection.h"

class MimeBuilder;

/** HTTP request. Provides routines to handle HTTP requests. */
class Http : public Connection {
    /// Received headers.
    std::list<std::string> m_Headers;

    std::string m_ReplyLine;

    int m_ReplyCode;

    bool doRequest(const Url& host, std::string request, MimeBuilder* body, std::ostream& out);
 public:

    static void setProxy(const Url& proxy);

    static const Url& getProxy();

    bool downloadFile(const Url& file, std::ostream& out);

    bool post(const Url& file, MimeBuilder& body, std::ostream& out);

    void enumerateHeaders(ValueEnumerator<std::string>& e);

    /** Get last reply code (e.g.\ 404). */
    int getReplyCode() const
        { return m_ReplyCode; }

    /** Get last reply line (e.g.\ "404 Not Found"). */
    std::string getReplyLine() const
        { return m_ReplyLine; }

    /** Check whether the last reply indicated a successful download. */
    bool isSuccessfulReply() const
        { return m_ReplyCode == 200 /* OK */; }

    std::string getHeader(std::string name);
};

#endif
