/**
  *  \file netconfig.cpp
  *  \brief Network Configuration
  */
#include "netconfig.h"
#include "dialogs.h"
#include "net/smtp.h"
#include "net/http.h"
#include "util.h"
#include "api.h"

static BOOL CALLBACK
theNetConfigDialogProc(HWND wnd, UINT msg, WPARAM wparam, LPARAM lparam)
{
    switch (msg) {
     case WM_INITDIALOG:
        SetFocus(GetDlgItem(wnd, ID_NET_MAILADDRESS));
        SetDlgItemText(wnd, ID_NET_MAILADDRESS, Smtp::getFromAddress().c_str());
        SetDlgItemText(wnd, ID_NET_SMTPSERVER,  Smtp::getServer().c_str());
        if (Smtp::getPort() != 25 /* FIXME magic number */)
            SetDlgItemText(wnd, ID_NET_SMTPPORT, itoa(Smtp::getPort()).c_str());
        SetDlgItemText(wnd, ID_NET_HTTPPROXY,   Http::getProxy().toString().c_str());
        return false;
     case WM_COMMAND: {
        int n = LOWORD(wparam);
        if (n == IDOK) {
            std::string mailaddr = getDlgItemString(wnd, ID_NET_MAILADDRESS);
            std::string mailserver = getDlgItemString(wnd, ID_NET_SMTPSERVER);
            std::string proxys = getDlgItemString(wnd, ID_NET_HTTPPROXY);
            std::string mailports = getDlgItemString(wnd, ID_NET_SMTPPORT);
            int mailport = -1;
            Url proxy;
            if (mailports.size() && !atoi(mailports, mailport)) {
                SetFocus(GetDlgItem(wnd, ID_NET_SMTPPORT));
                MessageBeep(-1U);
            } else if (proxys.size() && !proxy.parse(proxys)) {
                SetFocus(GetDlgItem(wnd, ID_NET_HTTPPROXY));
                MessageBeep(-1U);
            } else {
                Smtp::setServer(mailserver, mailport);
                Smtp::setFromAddress(mailaddr);
                Http::setProxy(proxy);
                EndDialog(wnd, 1);
            }
        }
        if (n == IDCANCEL)
            EndDialog(wnd, 0);
        return true;
     }
     default:
        return false;
    }
}

void
doNetConfig(HWND parent)
{
    DialogBox(GetModuleHandle(0), MAKEINTRESOURCE(IDD_NETCONFIG), parent, theNetConfigDialogProc);
}
